<template>
  <win-sm :title="setting.title" @close="close" :width="'800px'">
    <el-form ref="ruleForm" :model="formData" :rules="rules" class="demo-ruleForm" label-width="100px">
      <el-form-item label="编号" prop="code">
        <el-input v-model="formData.code" clearable maxlength="20" show-word-limit style="width: 100%"/>
      </el-form-item>
      <el-form-item label="机构名称" prop="name">
        <el-input v-model="formData.name" clearable maxlength="20" show-word-limit style="width: 100%"/>
      </el-form-item>
      <el-form-item label="状态" prop="status">
        <el-radio-group v-model="formData.status">
          <el-radio :label="1" border>启用</el-radio>
          <el-radio :label="0" border>禁用</el-radio>
        </el-radio-group>
      </el-form-item>
      <el-form-item label="备注" prop="summary">
        <el-input
          v-model="formData.summary"
          type="textarea"
          :rows="3"
          maxlength="100"
          show-word-limit
        />
      </el-form-item>
    </el-form>
    <div slot="footer" align="center" class="dialog-footer">
      <my-button name="取消" site="form" @click="close"/>
      <my-button name="保存" site="form" @click="save"/>
    </div>
  </win-sm>
</template>

<script>
import winSm from '@/components/win/win-sm'
import myButton from '@/components/myButton/myButton'
import * as finsystenant from '@/api/baseSetting/finsystenant'
import {addTenant, editTenant} from "@/api/baseSetting/finsystenant";

export default {
  components: {winSm, myButton},
  props: {
    setting: {
      type: Object,
      default: () => {
      }
    }
  },
  data() {
    return {
      checkAll: false,
      checkedList: [],
      formData: {
        code: '',
        name: '',
        status: 1,
        summary: '',
        parentId: '',
      },
      rules: {
        code: [
          {required: true, message: '请输入机构编号', trigger: 'blur'}
        ],
        name: [
          {required: true, message: '请输入机构名称', trigger: 'blur'}
        ]
      }
    }
  },
  created() {
    if(this.setting.info){
      this.formData = Object.assign({},JSON.parse(this.setting.info))
    }
  },
  methods: {
    getEditInfo(id){

    },
    close() {
      this.$emit('close')
    },
    toNumber(str) {
      const num = parseInt(str);
      return isNaN(num) ? "0" : num;
    },
    save() {
      // 验证编号是不是0开头
      let code = this.formData.code;
      let tempCode = this.toNumber(code)
      console.log("拿到的code  "+ code)
      console.log("拿到返回的的code  "+ tempCode)
      if(this.toNumber(code) === "0"){
        this.$message.error('编号必须为数字且不以0开头')
        return;
      }
      if(tempCode != code){
        this.$message.error('编号必须为数字且不以0开头')
        return;
      }
      if(code.startsWith("0")){
        this.$message.error('编号必须为数字且不以0开头')
        return;
      }
      this.$refs.ruleForm.validate((valid) => {
        if (valid) {
          const params = Object.assign({}, this.formData)
          if(this.setting.id){
            // 编辑接口
            finsystenant.editTenant(params).then(res => {
              if (res) {
                this.$message.success('保存成功！')
                this.close()
                this.$emit('search')
              } else {
                this.$message.error('保存失败')
              }
            })
          }else{
            params.parentId = this.setting.orgId
            finsystenant.addTenant(params).then(res => {
              if (res) {
                this.$message.success('保存成功！')
                this.close()
                this.$emit('search')
              } else {
                this.$message.error('保存失败')
              }
            })
          }
        } else {
          this.$message.error('校验未通过，请检查。')
        }
      })
    }
  }
}
</script>
